/****************************************************************************
** Meta object code from reading C++ file 'kdeplatformfiledialogbase_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../plasma-integration-6.6.90/qt6/src/platformtheme/kdeplatformfiledialogbase_p.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kdeplatformfiledialogbase_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN25KDEPlatformFileDialogBaseE_t {};
} // unnamed namespace

template <> constexpr inline auto KDEPlatformFileDialogBase::qt_create_metaobjectdata<qt_meta_tag_ZN25KDEPlatformFileDialogBaseE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KDEPlatformFileDialogBase",
        "closed",
        "",
        "fileSelected",
        "QUrl",
        "file",
        "filesSelected",
        "QList<QUrl>",
        "files",
        "currentChanged",
        "path",
        "directoryEntered",
        "directory",
        "filterSelected",
        "filter"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'closed'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fileSelected'
        QtMocHelpers::SignalData<void(const QUrl &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Signal 'filesSelected'
        QtMocHelpers::SignalData<void(const QList<QUrl> &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'currentChanged'
        QtMocHelpers::SignalData<void(const QUrl &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 10 },
        }}),
        // Signal 'directoryEntered'
        QtMocHelpers::SignalData<void(const QUrl &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 12 },
        }}),
        // Signal 'filterSelected'
        QtMocHelpers::SignalData<void(const QString &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KDEPlatformFileDialogBase, qt_meta_tag_ZN25KDEPlatformFileDialogBaseE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KDEPlatformFileDialogBase::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25KDEPlatformFileDialogBaseE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25KDEPlatformFileDialogBaseE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN25KDEPlatformFileDialogBaseE_t>.metaTypes,
    nullptr
} };

void KDEPlatformFileDialogBase::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KDEPlatformFileDialogBase *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->closed(); break;
        case 1: _t->fileSelected((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 2: _t->filesSelected((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1]))); break;
        case 3: _t->currentChanged((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 4: _t->directoryEntered((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 5: _t->filterSelected((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KDEPlatformFileDialogBase::*)()>(_a, &KDEPlatformFileDialogBase::closed, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KDEPlatformFileDialogBase::*)(const QUrl & )>(_a, &KDEPlatformFileDialogBase::fileSelected, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KDEPlatformFileDialogBase::*)(const QList<QUrl> & )>(_a, &KDEPlatformFileDialogBase::filesSelected, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KDEPlatformFileDialogBase::*)(const QUrl & )>(_a, &KDEPlatformFileDialogBase::currentChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (KDEPlatformFileDialogBase::*)(const QUrl & )>(_a, &KDEPlatformFileDialogBase::directoryEntered, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (KDEPlatformFileDialogBase::*)(const QString & )>(_a, &KDEPlatformFileDialogBase::filterSelected, 5))
            return;
    }
}

const QMetaObject *KDEPlatformFileDialogBase::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KDEPlatformFileDialogBase::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25KDEPlatformFileDialogBaseE_t>.strings))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int KDEPlatformFileDialogBase::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void KDEPlatformFileDialogBase::closed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KDEPlatformFileDialogBase::fileSelected(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void KDEPlatformFileDialogBase::filesSelected(const QList<QUrl> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void KDEPlatformFileDialogBase::currentChanged(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void KDEPlatformFileDialogBase::directoryEntered(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void KDEPlatformFileDialogBase::filterSelected(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}
QT_WARNING_POP
